import dataclasses

from yib import yconsole


console = yconsole.Console(stderr=True)


@dataclasses.dataclass
class Package:
    pypi: str
    # The crawler will crawl URLs with the same prefix until the last slash.
    index_url: str
    namespaces: list[str] = dataclasses.field(default_factory=list)
    exclude_root_urls: list[str] = dataclasses.field(default_factory=list)

    def __post_init__(self):
        if not self.namespaces:
            self.namespaces = [self.pypi.replace("-", "_")]

    def is_cpython(self):
        return self.pypi == "__python__"


# fmt: off
_packages = [
    Package(
        pypi="__python__",
        index_url="https://docs.python.org/3/library",
        exclude_root_urls=[
            "https://docs.python.org/3/copyright.html",  # Conflict with built-in copyright.
        ],
    ),
    Package(pypi="attrs", namespaces=["attrs", "attr"], index_url="https://www.attrs.org/en/stable/"),
    Package(pypi="boto3", index_url="https://boto3.amazonaws.com/v1/documentation/api/latest/index.html", exclude_root_urls=["https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/"]),  # TODO: Support boto services
    Package(pypi="botocore", index_url="https://botocore.amazonaws.com/v1/documentation/api/latest/index.html", exclude_root_urls=["https://botocore.amazonaws.com/v1/documentation/api/latest/reference/services/"]),  # TODO: Support boto services
    Package(pypi="charset-normalizer", index_url="https://charset-normalizer.readthedocs.io/en/latest/"),
    Package(pypi="cryptography", index_url="https://cryptography.io/en/latest/"),
    Package(pypi="fsspec", index_url="https://filesystem-spec.readthedocs.io/en/latest/"),
    Package(pypi="google-api-core", namespaces=["google.api_core"], index_url="https://googleapis.dev/python/google-api-core/latest/"),
    Package(pypi="numpy", index_url="https://numpy.org/doc/stable/reference/index.html"),
    Package(pypi="packaging", index_url="https://packaging.pypa.io/en/stable/"),
    Package(pypi="pandas", index_url="https://pandas.pydata.org/docs/reference/index.html"),
    Package(pypi="protobuf", namespaces=["google.protobuf"], index_url="https://googleapis.dev/python/protobuf/latest/"),
    Package(pypi="pydantic-core", index_url="https://docs.pydantic.dev/latest/"),
    Package(pypi="pydantic", index_url="https://docs.pydantic.dev/latest/"),
    Package(pypi="python-dateutil", namespaces=["dateutil"], index_url="https://dateutil.readthedocs.io/en/stable/"),
    Package(pypi="requests", index_url="https://requests.readthedocs.io/en/latest/"),
    Package(pypi="s3fs", index_url="https://s3fs.readthedocs.io/en/latest/"),
    Package(pypi="setuptools", index_url="https://setuptools.pypa.io/en/latest/"),
    Package(pypi="six", index_url="https://six.readthedocs.io/"),
    Package(pypi="typing-extensions", index_url="https://typing-extensions.readthedocs.io/en/latest/"),
    Package(pypi="urllib3", index_url="https://urllib3.readthedocs.io/en/stable/reference/index.html"),
    Package(pypi="platformdirs", index_url="https://platformdirs.readthedocs.io/en/latest/"),
    Package(pypi="click", index_url="https://click.palletsprojects.com/en/stable/"),
    Package(pypi="grpcio", namespaces=["grpc"], index_url="https://grpc.github.io/grpc/python/index.html"),
    Package(pypi="jinja2", index_url="https://jinja.palletsprojects.com/en/latest/"),
    Package(pypi="pyasn1", index_url="https://pyasn1.readthedocs.io/en/latest/contents.html"),
    Package(pypi="h11", index_url="https://h11.readthedocs.io/en/latest/"),
    Package(pypi="filelock", index_url="https://py-filelock.readthedocs.io/en/latest/"),
    Package(pypi="aiohttp", index_url="https://docs.aiohttp.org/en/stable/"),
    Package(pypi="cachetools", index_url="https://cachetools.readthedocs.io/en/latest/"),
    Package(pypi="pluggy", index_url="https://pluggy.readthedocs.io/en/latest/"),
    Package(pypi="markupsafe", index_url="https://markupsafe.palletsprojects.com/en/stable/"),
    Package(pypi="scipy", index_url="https://docs.scipy.org/doc/scipy/reference/index.html"),
    Package(pypi="propcache", index_url="https://propcache.aio-libs.org/en/latest/"),
    Package(pypi="pathspec", index_url="https://python-path-specification.readthedocs.io/en/latest/index.html"),
    Package(pypi="aiosignal", index_url="https://aiosignal.aio-libs.org/en/stable/"),
    Package(pypi="pyOpenSSL", namespaces=["OpenSSL"], index_url="https://www.pyopenssl.org/en/latest/"),
    Package(pypi="oauthlib", index_url="https://oauthlib.readthedocs.io/en/latest/"),
    Package(pypi="requests-toolbelt", index_url="https://toolbelt.readthedocs.io/en/latest/index.html"),
    Package(pypi="azure-identity", namespaces=["azure.identity"], index_url="https://azuresdkdocs.z19.web.core.windows.net/python/azure-identity/latest/index.html"),
    Package(pypi="distlib", index_url="https://distlib.readthedocs.io/en/latest/"),
    Package(pypi="pillow", namespaces=["PIL"], index_url="https://pillow.readthedocs.io/en/stable/"),
    Package(pypi="frozenlist", index_url="https://frozenlist.aio-libs.org/en/latest/"),
    Package(pypi="pyparsing", index_url="https://pyparsing-docs.readthedocs.io/en/latest/"),
    Package(pypi="tomlkit", index_url="https://tomlkit.readthedocs.io/en/latest/"),
    Package(pypi="rich", index_url="https://rich.readthedocs.io/en/latest/"),
    Package(pypi="sqlalchemy", index_url="https://docs.sqlalchemy.org/en/20/"),
    Package(pypi="requests-oauthlib", index_url="https://requests-oauthlib.readthedocs.io/en/latest/"),
    Package(pypi="yarl", index_url="https://yarl.aio-libs.org/en/latest/"),
    Package(pypi="multidict", index_url="https://multidict.aio-libs.org/en/stable/"),
    Package(pypi="pyarrow", index_url="https://arrow.apache.org/docs/python/api.html"),
    Package(pypi="sniffio", index_url="https://sniffio.readthedocs.io/en/latest/"),
    Package(pypi="jsonschema", index_url="https://python-jsonschema.readthedocs.io/en/stable/"),
    Package(pypi="google-auth", namespaces=["google.auth"], index_url="https://googleapis.dev/python/google-auth/latest/"),
    Package(pypi="pyjwt", namespaces=["jwt"], index_url="https://pyjwt.readthedocs.io/en/stable/"),
    Package(pypi="anyio", index_url="https://anyio.readthedocs.io/en/stable/"),
    Package(pypi="psutil", index_url="https://psutil.readthedocs.io/en/latest/"),
    Package(pypi="wrapt", index_url="https://wrapt.readthedocs.io/en/master/"),
    Package(pypi="pygments", index_url="https://pygments.org/docs/api/"),
    Package(pypi="rpds-py", namespaces=["rpds"], index_url="https://rpds.readthedocs.io/en/latest/"),
    Package(pypi="pytest", index_url="https://docs.pytest.org/en/stable/reference/index.html"),
    Package(pypi="libcst", index_url="https://libcst.readthedocs.io/en/latest/"),
    Package(pypi="numba", index_url="https://numba.readthedocs.io/en/stable/reference/index.html"),
    Package(pypi="trio", index_url="https://trio.readthedocs.io/en/stable/"),
    Package(pypi="tox", index_url="https://tox.wiki/en/stable/"),
    Package(pypi="h5py", index_url="https://docs.h5py.org/en/stable/"),
    Package(pypi="cattrs", index_url="https://catt.rs/en/stable/"),
    Package(pypi="nbformat", index_url="https://nbformat.readthedocs.io/en/latest/"),
    Package(pypi="semver", index_url="https://python-semver.readthedocs.io/en/latest/"),
    Package(pypi="aioitertools", index_url="https://aioitertools.omnilib.dev/en/stable/"),
    Package(pypi="torch", index_url="https://docs.pytorch.org/docs/stable/index.html"),
    Package(pypi="arrow", index_url="https://arrow.readthedocs.io/en/latest/"),
    Package(pypi="apache-beam", index_url="https://beam.apache.org/releases/pydoc/current/"),
    Package(pypi="fastapi", index_url="https://fastapi.tiangolo.com/reference/"),
    Package(pypi="flask", index_url="https://flask.palletsprojects.com/en/stable/"),
    Package(pypi="fastjsonschema", index_url="https://horejsek.github.io/python-fastjsonschema/"),
    Package(pypi="jupyter-core", index_url="https://jupyter-core.readthedocs.io/en/latest/"),
    Package(pypi="more-itertools", index_url="https://more-itertools.readthedocs.io/en/stable/"),
    Package(pypi="werkzeug", index_url="https://werkzeug.palletsprojects.com/en/stable/"),
    Package(pypi="scikit-learn", namespaces=["sklearn"], index_url="https://scikit-learn.org/stable/api/index.html"),
    Package(pypi="coverage", index_url="https://coverage.readthedocs.io/en/latest/"),
    Package(pypi="matplotlib", index_url="https://matplotlib.org/stable/api/index.html"),
    Package(pypi="networkx", index_url="https://networkx.org/documentation/stable/reference/index.html"),
    Package(pypi="ipython", namespaces=["IPython"], index_url="https://ipython.readthedocs.io/en/stable/"),
    Package(pypi="httplib2", index_url="https://httplib2.readthedocs.io/en/latest/"),
    Package(pypi="cyclopts", index_url="https://cyclopts.readthedocs.io/en/latest/"),
    Package(pypi="yib", index_url="https://yib.readthedocs.io/en/latest/"),
    Package(pypi="passlib", index_url="https://passlib.readthedocs.io/en/stable/"),
    Package(pypi="jax", index_url="https://docs.jax.dev/en/latest/jax.html"),
    Package(pypi="asn1", index_url="https://python-asn1.readthedocs.io/en/latest/"),
    Package(pypi="django-phonenumber-field", namespaces=["phonenumber_field"], index_url="https://django-phonenumber-field.readthedocs.io/en/latest/"),
    Package(pypi="sounddevice", index_url="https://python-sounddevice.readthedocs.io/en/latest/"),
    Package(pypi="prompt-toolkit", index_url="https://python-prompt-toolkit.readthedocs.io/en/latest/"),
    Package(pypi="bidict", index_url="https://bidict.readthedocs.io/en/main/"),
    Package(pypi="django-tables2", index_url="https://django-tables2.readthedocs.io/en/latest/"),
    Package(pypi="pikepdf", index_url="https://pikepdf.readthedocs.io/en/latest/"),
    Package(pypi="androguard", index_url="https://androguard.readthedocs.io/en/latest/"),
    Package(pypi="asyncstdlib", index_url="https://asyncstdlib.readthedocs.io/en/stable/"),
    Package(pypi="sigtools", index_url="https://sigtools.readthedocs.io/en/stable/"),
    Package(pypi="domdf-python-tools", index_url="https://domdf-python-tools.readthedocs.io/en/latest/"),
    Package(pypi="breathe", index_url="https://breathe.readthedocs.io/en/latest/"),
    Package(pypi="alabaster", index_url="https://alabaster.readthedocs.io/en/latest/"),
    Package(pypi="pydeequ", index_url="https://pydeequ.readthedocs.io/en/latest/"),
    Package(pypi="django-appconf", namespaces=["appconf"], index_url="https://django-appconf.readthedocs.io/en/latest/"),
    Package(pypi="path", index_url="https://path.readthedocs.io/en/latest/"),
    Package(pypi="python-gitlab", namespaces=["gitlab"], index_url="https://python-gitlab.readthedocs.io/en/stable/"),
    Package(pypi="djangorestframework-simplejwt", namespaces=["rest_framework_simplejwt"], index_url="https://django-rest-framework-simplejwt.readthedocs.io/en/latest/"),
    Package(pypi="django-otp", index_url="https://django-otp-official.readthedocs.io/en/stable/"),
    Package(pypi="django-compressor", namespaces=["compressor"], index_url="https://django-compressor.readthedocs.io/en/stable/"),
    Package(pypi="django-auditlog", namespaces=["auditlog"], index_url="https://django-auditlog.readthedocs.io/en/latest/"),
    Package(pypi="jaxtyping", index_url="https://docs.kidger.site/jaxtyping/"),
    Package(pypi="python-frontmatter", namespaces=["frontmatter"], index_url="https://python-frontmatter.readthedocs.io/en/latest/"),
    Package(pypi="entrypoints", index_url="https://entrypoints.readthedocs.io/en/latest/"),
    Package(pypi="eventlet", index_url="https://eventlet.readthedocs.io/en/latest/"),
    Package(pypi="msal", namespaces=["msal"], index_url="https://msal-python.readthedocs.io/en/latest/"),
    Package(pypi="pyproject-hooks", index_url="https://pyproject-hooks.readthedocs.io/en/latest/"),
    Package(pypi="plumbum", index_url="https://plumbum.readthedocs.io/en/latest/"),
    Package(pypi="livereload", index_url="https://livereload.readthedocs.io/en/latest/"),
    Package(pypi="django-axes", namespaces=["axes"], index_url="https://django-axes.readthedocs.io/en/latest/"),
    Package(pypi="pylibsrtp", index_url="https://pylibsrtp.readthedocs.io/en/latest/"),
    Package(pypi="timezonefinder", index_url="https://timezonefinder.readthedocs.io/en/latest/"),
    Package(pypi="selectolax", index_url="https://selectolax.readthedocs.io/en/latest/"),
    Package(pypi="yamllint", index_url="https://yamllint.readthedocs.io/en/stable/"),
    Package(pypi="chardet", index_url="https://chardet.readthedocs.io/en/latest/"),
    Package(pypi="aiodocker", index_url="https://aiodocker.readthedocs.io/en/latest/"),
    Package(pypi="jsonpickle", index_url="https://jsonpickle.readthedocs.io/en/latest/"),
    Package(pypi="click-option-group", index_url="https://click-option-group.readthedocs.io/en/latest/"),
    Package(pypi="josepy", index_url="https://josepy.readthedocs.io/en/stable/"),
    Package(pypi="cmd2", index_url="https://cmd2.readthedocs.io/en/stable/"),
    Package(pypi="blessings", index_url="https://blessings.readthedocs.io/en/latest/"),
    Package(pypi="eth-account", index_url="https://eth-account.readthedocs.io/en/stable/"),
    Package(pypi="dataclass-wizard", index_url="https://dataclass-wizard.readthedocs.io/en/latest/"),
    Package(pypi="hdbscan", index_url="https://hdbscan.readthedocs.io/en/latest/"),
    Package(pypi="pyod", index_url="https://pyod.readthedocs.io/en/latest/"),
    Package(pypi="convertdate", index_url="https://convertdate.readthedocs.io/en/latest/"),
    Package(pypi="py7zr", index_url="https://py7zr.readthedocs.io/en/latest/"),
    Package(pypi="flashtext", index_url="https://flashtext.readthedocs.io/en/latest/"),
    Package(pypi="plpygis", index_url="https://plpygis.readthedocs.io/en/stable/"),
    Package(pypi="tablib", index_url="https://tablib.readthedocs.io/en/stable/"),
    Package(pypi="pathlib-abc", index_url="https://pathlib-abc.readthedocs.io/en/latest/"),
    Package(pypi="pyglet", index_url="https://pyglet.readthedocs.io/en/latest/"),
    Package(pypi="phik", index_url="https://phik.readthedocs.io/en/latest/"),
    Package(pypi="lxml-html-clean", index_url="https://lxml-html-clean.readthedocs.io/en/latest/"),
    Package(pypi="boltons", index_url="https://boltons.readthedocs.io/en/latest/"),
    Package(pypi="aiortc", index_url="https://aiortc.readthedocs.io/en/latest/"),
    Package(pypi="pyluach", index_url="https://pyluach.readthedocs.io/en/latest/"),
    Package(pypi="pynamodb", index_url="https://pynamodb.readthedocs.io/en/stable/"),
    Package(pypi="flask-socketio", index_url="https://flask-socketio.readthedocs.io/en/latest/"),
    Package(pypi="ipykernel", index_url="https://ipykernel.readthedocs.io/en/stable/"),
    Package(pypi="troposphere", index_url="https://troposphere.readthedocs.io/en/latest/"),
    Package(pypi="setuptools-scm", index_url="https://setuptools-scm.readthedocs.io/en/latest/"),
    Package(pypi="pbs-installer", index_url="https://pbs-installer.readthedocs.io/en/latest/"),
    Package(pypi="pyomo", index_url="https://pyomo.readthedocs.io/en/stable/"),
    Package(pypi="donfig", index_url="https://donfig.readthedocs.io/en/latest/"),
    Package(pypi="gtts", index_url="https://gtts.readthedocs.io/en/latest/"),
    Package(pypi="simple-websocket", index_url="https://simple-websocket.readthedocs.io/en/latest/"),
    Package(pypi="outcome", index_url="https://outcome.readthedocs.io/en/latest/"),
    Package(pypi="scikit-build-core", index_url="https://scikit-build-core.readthedocs.io/en/latest/"),
    Package(pypi="imageio", index_url="https://imageio.readthedocs.io/en/stable/"),
    Package(pypi="parver", index_url="https://parver.readthedocs.io/en/stable/"),
    Package(pypi="twine", index_url="https://twine.readthedocs.io/en/stable/"),
    Package(pypi="anytree", index_url="https://anytree.readthedocs.io/en/latest/"),
    Package(pypi="rdflib", index_url="https://rdflib.readthedocs.io/en/stable/"),
    Package(pypi="fasteners", index_url="https://fasteners.readthedocs.io/en/latest/"),
    Package(pypi="aioice", index_url="https://aioice.readthedocs.io/en/latest/"),
    Package(pypi="marshmallow", index_url="https://marshmallow.readthedocs.io/en/latest/"),
    Package(pypi="unearth", index_url="https://unearth.readthedocs.io/en/latest/"),
    Package(pypi="keyring", index_url="https://keyring.readthedocs.io/en/latest/"),
    Package(pypi="pymemcache", index_url="https://pymemcache.readthedocs.io/en/latest/"),
    Package(pypi="trafilatura", index_url="https://trafilatura.readthedocs.io/en/latest/"),
    Package(pypi="zipp", index_url="https://zipp.readthedocs.io/en/latest/"),
    Package(pypi="grpc-interceptor", index_url="https://grpc-interceptor.readthedocs.io/en/latest/"),
    Package(pypi="rtree", index_url="https://rtree.readthedocs.io/en/latest/"),
    Package(pypi="nutree", index_url="https://nutree.readthedocs.io/en/latest/"),
    Package(pypi="pgeocode", index_url="https://pgeocode.readthedocs.io/en/latest/"),
    Package(pypi="pyvis", index_url="https://pyvis.readthedocs.io/en/latest/"),
    Package(pypi="aiokafka", index_url="https://aiokafka.readthedocs.io/en/stable/"),
    Package(pypi="bleach", index_url="https://bleach.readthedocs.io/en/latest/"),
    Package(pypi="bottleneck", index_url="https://bottleneck.readthedocs.io/en/latest/"),
    Package(pypi="terminado", index_url="https://terminado.readthedocs.io/en/latest/"),
    Package(pypi="itemloaders", index_url="https://itemloaders.readthedocs.io/en/latest/"),
    Package(pypi="django-celery-beat", index_url="https://django-celery-beat.readthedocs.io/en/latest/"),
    Package(pypi="qh3", index_url="https://qh3.readthedocs.io/en/latest/"),
    Package(pypi="jsonlines", index_url="https://jsonlines.readthedocs.io/en/latest/"),
    Package(pypi="sqllineage", index_url="https://sqllineage.readthedocs.io/en/latest/"),
    Package(pypi="kiwisolver", index_url="https://kiwisolver.readthedocs.io/en/latest/"),
    Package(pypi="javaproperties", index_url="https://javaproperties.readthedocs.io/en/stable/"),
    Package(pypi="nameparser", index_url="https://nameparser.readthedocs.io/en/latest/"),
    Package(pypi="versioningit", index_url="https://versioningit.readthedocs.io/en/stable/"),
    Package(pypi="pandera", index_url="https://pandera.readthedocs.io/en/stable/"),
    Package(pypi="mpi4py", index_url="https://mpi4py.readthedocs.io/en/stable/"),
    Package(pypi="holidays", index_url="https://holidays.readthedocs.io/en/latest/"),
    Package(pypi="kneed", index_url="https://kneed.readthedocs.io/en/stable/"),
    Package(pypi="aioquic", index_url="https://aioquic.readthedocs.io/en/latest/"),
    Package(pypi="py", index_url="https://py.readthedocs.io/en/latest/"),
    Package(pypi="xgboost", index_url="https://xgboost.readthedocs.io/en/stable/"),
    Package(pypi="pywinauto", index_url="https://pywinauto.readthedocs.io/en/latest/"),
    Package(pypi="rpyc", index_url="https://rpyc.readthedocs.io/en/latest/"),
    Package(pypi="autobahn", index_url="https://autobahn.readthedocs.io/en/latest/"),
    Package(pypi="schemathesis", index_url="https://schemathesis.readthedocs.io/en/stable/"),
    Package(pypi="junitparser", index_url="https://junitparser.readthedocs.io/en/latest/"),
    Package(pypi="rstcheck-core", index_url="https://rstcheck-core.readthedocs.io/en/latest/"),
    Package(pypi="hachoir", index_url="https://hachoir.readthedocs.io/en/latest/"),
    Package(pypi="pyttsx3", index_url="https://pyttsx3.readthedocs.io/en/latest/"),
    Package(pypi="django-mysql", index_url="https://django-mysql.readthedocs.io/en/latest/"),
    Package(pypi="python-statemachine", index_url="https://python-statemachine.readthedocs.io/en/latest/"),
    Package(pypi="trustme", index_url="https://trustme.readthedocs.io/en/latest/"),
    Package(pypi="urlextract", index_url="https://urlextract.readthedocs.io/en/latest/"),
    Package(pypi="executor", index_url="https://executor.readthedocs.io/en/latest/"),
    Package(pypi="pyqtgraph", index_url="https://pyqtgraph.readthedocs.io/en/latest/"),
    Package(pypi="django-auth-ldap", index_url="https://django-auth-ldap.readthedocs.io/en/latest/"),
    Package(pypi="cachelib", index_url="https://cachelib.readthedocs.io/en/stable/"),
    Package(pypi="w3lib", index_url="https://w3lib.readthedocs.io/en/latest/"),
    Package(pypi="recordlinkage", index_url="https://recordlinkage.readthedocs.io/en/latest/"),
    Package(pypi="ddtrace", index_url="https://ddtrace.readthedocs.io/en/stable/"),
    Package(pypi="numpydoc", index_url="https://numpydoc.readthedocs.io/en/latest/"),
    Package(pypi="bleak", index_url="https://bleak.readthedocs.io/en/latest/"),
    Package(pypi="xhtml2pdf", index_url="https://xhtml2pdf.readthedocs.io/en/latest/"),
    Package(pypi="cssutils", index_url="https://cssutils.readthedocs.io/en/latest/"),
    Package(pypi="mmh3", index_url="https://mmh3.readthedocs.io/en/latest/"),
    Package(pypi="singledispatch", index_url="https://singledispatch.readthedocs.io/en/latest/"),
    Package(pypi="eth-rlp", index_url="https://eth-rlp.readthedocs.io/en/stable/"),
    Package(pypi="pillow-heif", index_url="https://pillow-heif.readthedocs.io/en/latest/"),
    Package(pypi="httpretty", index_url="https://httpretty.readthedocs.io/en/latest/"),
    Package(pypi="verboselogs", index_url="https://verboselogs.readthedocs.io/en/latest/"),
    Package(pypi="gcsfs", index_url="https://gcsfs.readthedocs.io/en/latest/"),
    Package(pypi="methodtools", index_url="https://methodtools.readthedocs.io/en/latest/"),
    Package(pypi="flask-restx", index_url="https://flask-restx.readthedocs.io/en/latest/"),
    Package(pypi="pyinstrument", index_url="https://pyinstrument.readthedocs.io/en/latest/"),
    Package(pypi="limits", index_url="https://limits.readthedocs.io/en/stable/"),
    Package(pypi="asttokens", index_url="https://asttokens.readthedocs.io/en/stable/"),
    Package(pypi="dictdiffer", index_url="https://dictdiffer.readthedocs.io/en/latest/"),
    Package(pypi="html5lib", index_url="https://html5lib.readthedocs.io/en/latest/"),
    Package(pypi="glom", index_url="https://glom.readthedocs.io/en/latest/"),
    Package(pypi="usort", index_url="https://usort.readthedocs.io/en/stable/"),
    Package(pypi="pebble", index_url="https://pebble.readthedocs.io/en/latest/"),
    Package(pypi="honcho", index_url="https://honcho.readthedocs.io/en/latest/"),
    Package(pypi="rfc3986", index_url="https://rfc3986.readthedocs.io/en/latest/"),
    Package(pypi="dependency-groups", index_url="https://dependency-groups.readthedocs.io/en/latest/"),
    Package(pypi="flupy", index_url="https://flupy.readthedocs.io/en/latest/"),
    Package(pypi="nox-poetry", index_url="https://nox-poetry.readthedocs.io/en/stable/"),
    Package(pypi="pynndescent", index_url="https://pynndescent.readthedocs.io/en/latest/"),
    Package(pypi="blinker", index_url="https://blinker.readthedocs.io/en/stable/"),
    Package(pypi="gptcache", index_url="https://gptcache.readthedocs.io/en/latest/"),
    Package(pypi="pygsheets", index_url="https://pygsheets.readthedocs.io/en/stable/"),
    Package(pypi="recurring-ical-events", index_url="https://recurring-ical-events.readthedocs.io/en/latest/"),
    Package(pypi="configupdater", index_url="https://configupdater.readthedocs.io/en/latest/"),
    Package(pypi="pandas-market-calendars", index_url="https://pandas-market-calendars.readthedocs.io/en/latest/"),
    Package(pypi="autodocsumm", index_url="https://autodocsumm.readthedocs.io/en/latest/"),
    Package(pypi="uritemplate", index_url="https://uritemplate.readthedocs.io/en/latest/"),
    Package(pypi="execnet", index_url="https://execnet.readthedocs.io/en/latest/"),
    Package(pypi="pymongo", index_url="https://pymongo.readthedocs.io/en/stable/"),
    Package(pypi="shap", index_url="https://shap.readthedocs.io/en/latest/"),
    Package(pypi="eth-abi", index_url="https://eth-abi.readthedocs.io/en/stable/"),
    Package(pypi="pydantic-xml", index_url="https://pydantic-xml.readthedocs.io/en/latest/"),
    Package(pypi="aiogoogle", index_url="https://aiogoogle.readthedocs.io/en/latest/"),
    Package(pypi="sagemaker", index_url="https://sagemaker.readthedocs.io/en/stable/"),
    Package(pypi="dotty-dict", index_url="https://dotty-dict.readthedocs.io/en/latest/"),
    Package(pypi="binaryornot", index_url="https://binaryornot.readthedocs.io/en/latest/"),
    Package(pypi="coloredlogs", index_url="https://coloredlogs.readthedocs.io/en/latest/"),
    Package(pypi="pytablewriter", index_url="https://pytablewriter.readthedocs.io/en/latest/"),
    Package(pypi="pypika", index_url="https://pypika.readthedocs.io/en/latest/"),
    Package(pypi="bitstruct", index_url="https://bitstruct.readthedocs.io/en/latest/"),
    Package(pypi="aiomysql", index_url="https://aiomysql.readthedocs.io/en/stable/"),
    Package(pypi="xmlschema", index_url="https://xmlschema.readthedocs.io/en/stable/"),
    Package(pypi="lazy", index_url="https://lazy.readthedocs.io/en/latest/"),
    Package(pypi="aiolimiter", index_url="https://aiolimiter.readthedocs.io/en/stable/"),
    Package(pypi="copier", index_url="https://copier.readthedocs.io/en/stable/"),
    Package(pypi="sshtunnel", index_url="https://sshtunnel.readthedocs.io/en/latest/"),
    Package(pypi="apeye", index_url="https://apeye.readthedocs.io/en/latest/"),
    Package(pypi="niquests", index_url="https://niquests.readthedocs.io/en/latest/"),
    Package(pypi="etils", index_url="https://etils.readthedocs.io/en/latest/"),
    Package(pypi="ntc-templates", index_url="https://ntc-templates.readthedocs.io/en/latest/"),
    Package(pypi="parso", index_url="https://parso.readthedocs.io/en/latest/"),
    Package(pypi="postmarker", index_url="https://postmarker.readthedocs.io/en/latest/"),
    Package(pypi="validator-collection", index_url="https://validator-collection.readthedocs.io/en/latest/"),
    Package(pypi="typeguard", index_url="https://typeguard.readthedocs.io/en/stable/"),
    Package(pypi="loguru", index_url="https://loguru.readthedocs.io/en/stable/"),
    Package(pypi="zict", index_url="https://zict.readthedocs.io/en/latest/"),
    Package(pypi="myst-nb", index_url="https://myst-nb.readthedocs.io/en/latest/"),
    Package(pypi="numcodecs", index_url="https://numcodecs.readthedocs.io/en/stable/"),
    Package(pypi="speechbrain", index_url="https://speechbrain.readthedocs.io/en/latest/"),
    Package(pypi="geopy", index_url="https://geopy.readthedocs.io/en/stable/"),
    Package(pypi="llvmlite", index_url="https://llvmlite.readthedocs.io/en/latest/"),
    Package(pypi="portalocker", index_url="https://portalocker.readthedocs.io/en/latest/"),
    Package(pypi="elementpath", index_url="https://elementpath.readthedocs.io/en/latest/"),
    Package(pypi="grapheme", index_url="https://grapheme.readthedocs.io/en/latest/"),
    Package(pypi="pytensor", index_url="https://pytensor.readthedocs.io/en/latest/"),
    Package(pypi="pyogrio", index_url="https://pyogrio.readthedocs.io/en/latest/"),
    Package(pypi="simplejson", index_url="https://simplejson.readthedocs.io/en/latest/"),
    Package(pypi="property-manager", index_url="https://property-manager.readthedocs.io/en/latest/"),
    Package(pypi="pysam", index_url="https://pysam.readthedocs.io/en/stable/"),
    Package(pypi="python-utils", index_url="https://python-utils.readthedocs.io/en/latest/"),
    Package(pypi="altgraph", index_url="https://altgraph.readthedocs.io/en/latest/"),
    Package(pypi="dbfread", index_url="https://dbfread.readthedocs.io/en/latest/"),
    Package(pypi="graypy", index_url="https://graypy.readthedocs.io/en/latest/"),
    Package(pypi="asammdf", index_url="https://asammdf.readthedocs.io/en/latest/"),
    Package(pypi="schemdraw", index_url="https://schemdraw.readthedocs.io/en/stable/"),
    Package(pypi="pymonetdb", index_url="https://pymonetdb.readthedocs.io/en/latest/"),
    Package(pypi="curated-transformers", index_url="https://curated-transformers.readthedocs.io/en/latest/"),
    Package(pypi="pyjson5", index_url="https://pyjson5.readthedocs.io/en/latest/"),
    Package(pypi="portend", index_url="https://portend.readthedocs.io/en/latest/"),
    Package(pypi="pytest-alembic", index_url="https://pytest-alembic.readthedocs.io/en/latest/"),
    Package(pypi="rply", index_url="https://rply.readthedocs.io/en/latest/"),
    Package(pypi="alexapy", index_url="https://alexapy.readthedocs.io/en/latest/"),
    Package(pypi="mdutils", index_url="https://mdutils.readthedocs.io/en/latest/"),
    Package(pypi="archspec", index_url="https://archspec.readthedocs.io/en/latest/"),
    Package(pypi="stumpy", index_url="https://stumpy.readthedocs.io/en/latest/"),
    Package(pypi="olefile", index_url="https://olefile.readthedocs.io/en/latest/"),
    Package(pypi="aiounittest", index_url="https://aiounittest.readthedocs.io/en/latest/"),
    Package(pypi="eth-typing", index_url="https://eth-typing.readthedocs.io/en/stable/"),
    Package(pypi="htmlmin", index_url="https://htmlmin.readthedocs.io/en/latest/"),
    Package(pypi="hypothesis", index_url="https://hypothesis.readthedocs.io/en/latest/"),
    Package(pypi="aiosmtplib", index_url="https://aiosmtplib.readthedocs.io/en/latest/"),
    Package(pypi="behave", index_url="https://behave.readthedocs.io/en/latest/"),
    Package(pypi="mwparserfromhell", index_url="https://mwparserfromhell.readthedocs.io/en/latest/"),
    Package(pypi="diceware", index_url="https://diceware.readthedocs.io/en/stable/"),
    Package(pypi="sphinx-toolbox", index_url="https://sphinx-toolbox.readthedocs.io/en/latest/"),
    Package(pypi="autoray", index_url="https://autoray.readthedocs.io/en/latest/"),
    Package(pypi="elasticsearch-dsl", index_url="https://elasticsearch-dsl.readthedocs.io/en/latest/"),
    Package(pypi="pint", index_url="https://pint.readthedocs.io/en/stable/"),
    Package(pypi="gql", index_url="https://gql.readthedocs.io/en/stable/"),
    Package(pypi="hyperlink", index_url="https://hyperlink.readthedocs.io/en/latest/"),
    Package(pypi="coolname", index_url="https://coolname.readthedocs.io/en/latest/"),
    Package(pypi="xlrd", index_url="https://xlrd.readthedocs.io/en/latest/"),
    Package(pypi="mplcursors", index_url="https://mplcursors.readthedocs.io/en/stable/"),
    Package(pypi="clize", index_url="https://clize.readthedocs.io/en/stable/"),
    Package(pypi="flask-mail", index_url="https://flask-mail.readthedocs.io/en/latest/"),
    Package(pypi="aiopg", index_url="https://aiopg.readthedocs.io/en/stable/"),
    Package(pypi="zarr", index_url="https://zarr.readthedocs.io/en/stable/"),
    Package(pypi="resampy", index_url="https://resampy.readthedocs.io/en/stable/"),
    Package(pypi="flask-session", index_url="https://flask-session.readthedocs.io/en/latest/"),
    Package(pypi="pympler", index_url="https://pympler.readthedocs.io/en/latest/"),
    Package(pypi="sqlparse", index_url="https://sqlparse.readthedocs.io/en/latest/"),
    Package(pypi="flatdict", index_url="https://flatdict.readthedocs.io/en/stable/"),
    Package(pypi="cbor2", index_url="https://cbor2.readthedocs.io/en/latest/"),
    Package(pypi="hijri-converter", index_url="https://hijri-converter.readthedocs.io/en/stable/"),
    Package(pypi="leidenalg", index_url="https://leidenalg.readthedocs.io/en/stable/"),
    Package(pypi="kazoo", index_url="https://kazoo.readthedocs.io/en/latest/"),
    Package(pypi="pymisp", index_url="https://pymisp.readthedocs.io/en/latest/"),
    Package(pypi="pexpect", index_url="https://pexpect.readthedocs.io/en/stable/"),
    Package(pypi="pytz-deprecation-shim", index_url="https://pytz-deprecation-shim.readthedocs.io/en/latest/"),
    Package(pypi="deprecated", index_url="https://deprecated.readthedocs.io/en/latest/"),
    Package(pypi="pytest-html", index_url="https://pytest-html.readthedocs.io/en/latest/"),
    Package(pypi="deep-translator", index_url="https://deep-translator.readthedocs.io/en/latest/"),
    Package(pypi="shapely", index_url="https://shapely.readthedocs.io/en/stable/"),
    Package(pypi="optree", index_url="https://optree.readthedocs.io/en/latest/"),
    Package(pypi="leather", index_url="https://leather.readthedocs.io/en/latest/"),
    Package(pypi="django-htmx", index_url="https://django-htmx.readthedocs.io/en/latest/"),
    Package(pypi="deepmerge", index_url="https://deepmerge.readthedocs.io/en/latest/"),
    Package(pypi="segno", index_url="https://segno.readthedocs.io/en/latest/"),
    Package(pypi="pygls", index_url="https://pygls.readthedocs.io/en/latest/"),
    Package(pypi="astor", index_url="https://astor.readthedocs.io/en/latest/"),
    Package(pypi="optuna-integration", index_url="https://optuna-integration.readthedocs.io/en/latest/"),
    Package(pypi="deprecation", index_url="https://deprecation.readthedocs.io/en/latest/"),
    Package(pypi="humanize", index_url="https://humanize.readthedocs.io/en/stable/"),
    Package(pypi="flask-admin", index_url="https://flask-admin.readthedocs.io/en/stable/"),
    Package(pypi="pydata-sphinx-theme", index_url="https://pydata-sphinx-theme.readthedocs.io/en/stable/"),
    Package(pypi="pem", index_url="https://pem.readthedocs.io/en/stable/"),
    Package(pypi="tempora", index_url="https://tempora.readthedocs.io/en/latest/"),
    Package(pypi="parsel", index_url="https://parsel.readthedocs.io/en/latest/"),
    Package(pypi="csvw", index_url="https://csvw.readthedocs.io/en/latest/"),
    Package(pypi="flask-oauthlib", index_url="https://flask-oauthlib.readthedocs.io/en/latest/"),
    Package(pypi="htmldate", index_url="https://htmldate.readthedocs.io/en/latest/"),
    Package(pypi="drf-spectacular", index_url="https://drf-spectacular.readthedocs.io/en/latest/"),
    Package(pypi="asyncssh", index_url="https://asyncssh.readthedocs.io/en/latest/"),
    Package(pypi="flask-jwt-extended", index_url="https://flask-jwt-extended.readthedocs.io/en/stable/"),
    Package(pypi="cookiecutter", index_url="https://cookiecutter.readthedocs.io/en/stable/"),
    Package(pypi="pandas-datareader", index_url="https://pandas-datareader.readthedocs.io/en/latest/"),
    Package(pypi="ml-collections", index_url="https://ml-collections.readthedocs.io/en/latest/"),
    Package(pypi="pfzy", index_url="https://pfzy.readthedocs.io/en/latest/"),
    Package(pypi="importlib-metadata", index_url="https://importlib-metadata.readthedocs.io/en/latest/"),
    Package(pypi="xmlsec", index_url="https://xmlsec.readthedocs.io/en/stable/"),
    Package(pypi="tslearn", index_url="https://tslearn.readthedocs.io/en/stable/"),
    Package(pypi="websockets", index_url="https://websockets.readthedocs.io/en/stable/"),
    Package(pypi="rasterio", index_url="https://rasterio.readthedocs.io/en/stable/"),
    Package(pypi="hexbytes", index_url="https://hexbytes.readthedocs.io/en/stable/"),
    Package(pypi="pyftpdlib", index_url="https://pyftpdlib.readthedocs.io/en/latest/"),
    Package(pypi="openapi-core", index_url="https://openapi-core.readthedocs.io/en/latest/"),
    Package(pypi="distro", index_url="https://distro.readthedocs.io/en/latest/"),
    Package(pypi="py-ecc", index_url="https://py-ecc.readthedocs.io/en/latest/"),
    Package(pypi="vine", index_url="https://vine.readthedocs.io/en/latest/"),
    Package(pypi="bezier", index_url="https://bezier.readthedocs.io/en/stable/"),
    Package(pypi="hist", index_url="https://hist.readthedocs.io/en/latest/"),
    Package(pypi="dateparser", index_url="https://dateparser.readthedocs.io/en/latest/"),
    Package(pypi="sqlakeyset", index_url="https://sqlakeyset.readthedocs.io/en/latest/"),
    Package(pypi="eth-utils", index_url="https://eth-utils.readthedocs.io/en/stable/"),
    Package(pypi="pytest-httpserver", index_url="https://pytest-httpserver.readthedocs.io/en/latest/"),
    Package(pypi="pylsqpack", index_url="https://pylsqpack.readthedocs.io/en/latest/"),
    Package(pypi="netaddr", index_url="https://netaddr.readthedocs.io/en/latest/"),
    Package(pypi="luigi", index_url="https://luigi.readthedocs.io/en/stable/"),
    Package(pypi="einx", index_url="https://einx.readthedocs.io/en/latest/"),
    Package(pypi="treelite", index_url="https://treelite.readthedocs.io/en/latest/"),
    Package(pypi="django-select2", index_url="https://django-select2.readthedocs.io/en/latest/"),
    Package(pypi="mlserver", index_url="https://mlserver.readthedocs.io/en/stable/"),
    Package(pypi="injector", index_url="https://injector.readthedocs.io/en/latest/"),
    Package(pypi="pymysql", index_url="https://pymysql.readthedocs.io/en/latest/"),
    Package(pypi="traitlets", index_url="https://traitlets.readthedocs.io/en/stable/"),
    Package(pypi="questionary", index_url="https://questionary.readthedocs.io/en/stable/"),
    Package(pypi="optax", index_url="https://optax.readthedocs.io/en/latest/"),
    Package(pypi="parsy", index_url="https://parsy.readthedocs.io/en/latest/"),
    Package(pypi="polling2", index_url="https://polling2.readthedocs.io/en/latest/"),
    Package(pypi="ldaptor", index_url="https://ldaptor.readthedocs.io/en/latest/"),
    Package(pypi="construct", index_url="https://construct.readthedocs.io/en/latest/"),
    Package(pypi="stix2", index_url="https://stix2.readthedocs.io/en/latest/"),
    Package(pypi="ipyparallel", index_url="https://ipyparallel.readthedocs.io/en/latest/"),
    Package(pypi="connexion", index_url="https://connexion.readthedocs.io/en/stable/"),
    Package(pypi="uritools", index_url="https://uritools.readthedocs.io/en/stable/"),
    Package(pypi="mizani", index_url="https://mizani.readthedocs.io/en/stable/"),
    Package(pypi="schedule", index_url="https://schedule.readthedocs.io/en/stable/"),
    Package(pypi="gspread-dataframe", index_url="https://gspread-dataframe.readthedocs.io/en/latest/"),
    Package(pypi="humanfriendly", index_url="https://humanfriendly.readthedocs.io/en/latest/"),
    Package(pypi="prov", index_url="https://prov.readthedocs.io/en/latest/"),
    Package(pypi="ecdsa", index_url="https://ecdsa.readthedocs.io/en/latest/"),
    Package(pypi="scapy", index_url="https://scapy.readthedocs.io/en/latest/"),
    Package(pypi="psygnal", index_url="https://psygnal.readthedocs.io/en/latest/"),
    Package(pypi="lkml", index_url="https://lkml.readthedocs.io/en/latest/"),
    Package(pypi="maison", index_url="https://maison.readthedocs.io/en/latest/"),
    Package(pypi="pypdf", index_url="https://pypdf.readthedocs.io/en/stable/"),
    Package(pypi="referencing", index_url="https://referencing.readthedocs.io/en/stable/"),
    Package(pypi="txaio", index_url="https://txaio.readthedocs.io/en/latest/"),
    Package(pypi="polib", index_url="https://polib.readthedocs.io/en/latest/"),
    Package(pypi="drf-yasg", index_url="https://drf-yasg.readthedocs.io/en/stable/"),
    Package(pypi="adtk", index_url="https://adtk.readthedocs.io/en/stable/"),
    Package(pypi="pyngrok", index_url="https://pyngrok.readthedocs.io/en/latest/"),
    Package(pypi="cython", index_url="https://cython.readthedocs.io/en/latest/"),
    Package(pypi="patsy", index_url="https://patsy.readthedocs.io/en/latest/"),
    Package(pypi="flask-oidc", index_url="https://flask-oidc.readthedocs.io/en/latest/"),
    Package(pypi="jsonref", index_url="https://jsonref.readthedocs.io/en/latest/"),
    Package(pypi="fiona", index_url="https://fiona.readthedocs.io/en/stable/"),
    Package(pypi="depyf", index_url="https://depyf.readthedocs.io/en/latest/"),
    Package(pypi="pymssql", index_url="https://pymssql.readthedocs.io/en/latest/"),
    Package(pypi="filterpy", index_url="https://filterpy.readthedocs.io/en/latest/"),
    Package(pypi="funcy", index_url="https://funcy.readthedocs.io/en/stable/"),
    Package(pypi="wirerope", index_url="https://wirerope.readthedocs.io/en/stable/"),
    Package(pypi="treelib", index_url="https://treelib.readthedocs.io/en/latest/"),
    Package(pypi="pydata-google-auth", index_url="https://pydata-google-auth.readthedocs.io/en/latest/"),
    Package(pypi="logzero", index_url="https://logzero.readthedocs.io/en/latest/"),
    Package(pypi="mmengine", index_url="https://mmengine.readthedocs.io/en/latest/"),
    Package(pypi="secretstorage", index_url="https://secretstorage.readthedocs.io/en/latest/"),
    Package(pypi="django-celery-results", index_url="https://django-celery-results.readthedocs.io/en/latest/"),
    Package(pypi="pylatexenc", index_url="https://pylatexenc.readthedocs.io/en/latest/"),
    Package(pypi="jupyter-contrib-nbextensions", index_url="https://jupyter-contrib-nbextensions.readthedocs.io/en/latest/"),
    Package(pypi="xsdata", index_url="https://xsdata.readthedocs.io/en/latest/"),
    Package(pypi="osmnx", index_url="https://osmnx.readthedocs.io/en/stable/"),
    Package(pypi="cssselect", index_url="https://cssselect.readthedocs.io/en/latest/"),
    Package(pypi="pynput", index_url="https://pynput.readthedocs.io/en/latest/"),
    Package(pypi="testpath", index_url="https://testpath.readthedocs.io/en/latest/"),
    Package(pypi="pynetbox", index_url="https://pynetbox.readthedocs.io/en/latest/"),
    Package(pypi="pytest-django", index_url="https://pytest-django.readthedocs.io/en/latest/"),
    Package(pypi="pyhmmer", index_url="https://pyhmmer.readthedocs.io/en/stable/"),
    Package(pypi="pika", index_url="https://pika.readthedocs.io/en/stable/"),
    Package(pypi="tld", index_url="https://tld.readthedocs.io/en/latest/"),
    Package(pypi="inflate64", index_url="https://inflate64.readthedocs.io/en/latest/"),
    Package(pypi="pymodbus", index_url="https://pymodbus.readthedocs.io/en/latest/"),
    Package(pypi="checkdigit", index_url="https://checkdigit.readthedocs.io/en/latest/"),
    Package(pypi="dict2css", index_url="https://dict2css.readthedocs.io/en/latest/"),
    Package(pypi="logbook", index_url="https://logbook.readthedocs.io/en/stable/"),
    Package(pypi="service-identity", index_url="https://service-identity.readthedocs.io/en/stable/"),
    Package(pypi="joblib", index_url="https://joblib.readthedocs.io/en/stable/"),
    Package(pypi="flask-httpauth", index_url="https://flask-httpauth.readthedocs.io/en/latest/"),
    Package(pypi="macholib", index_url="https://macholib.readthedocs.io/en/latest/"),
    Package(pypi="pyairtable", index_url="https://pyairtable.readthedocs.io/en/stable/"),
    Package(pypi="greenlet", index_url="https://greenlet.readthedocs.io/en/latest/"),
    Package(pypi="pamqp", index_url="https://pamqp.readthedocs.io/en/stable/"),
    Package(pypi="pyhamcrest", index_url="https://pyhamcrest.readthedocs.io/en/latest/"),
    Package(pypi="pytest-dependency", index_url="https://pytest-dependency.readthedocs.io/en/stable/"),
    Package(pypi="prettyprinter", index_url="https://prettyprinter.readthedocs.io/en/latest/"),
    Package(pypi="pytest-flake8", index_url="https://pytest-flake8.readthedocs.io/en/latest/"),
    Package(pypi="pgpy", index_url="https://pgpy.readthedocs.io/en/latest/"),
    Package(pypi="lomond", index_url="https://lomond.readthedocs.io/en/latest/"),
    Package(pypi="aiostream", index_url="https://aiostream.readthedocs.io/en/stable/"),
    Package(pypi="ops", index_url="https://ops.readthedocs.io/en/latest/"),
    Package(pypi="nh3", index_url="https://nh3.readthedocs.io/en/latest/"),
    Package(pypi="blessed", index_url="https://blessed.readthedocs.io/en/latest/"),
    Package(pypi="pytoolconfig", index_url="https://pytoolconfig.readthedocs.io/en/latest/"),
    Package(pypi="dataset", index_url="https://dataset.readthedocs.io/en/latest/"),
    Package(pypi="fastparquet", index_url="https://fastparquet.readthedocs.io/en/latest/"),
    Package(pypi="pytest-benchmark", index_url="https://pytest-benchmark.readthedocs.io/en/latest/"),
    Package(pypi="s2sphere", index_url="https://s2sphere.readthedocs.io/en/latest/"),
    Package(pypi="comtypes", index_url="https://comtypes.readthedocs.io/en/stable/"),
    Package(pypi="sanic", index_url="https://sanic.readthedocs.io/en/stable/"),
    Package(pypi="webcolors", index_url="https://webcolors.readthedocs.io/en/latest/"),
    Package(pypi="toolz", index_url="https://toolz.readthedocs.io/en/latest/"),
    Package(pypi="shillelagh", index_url="https://shillelagh.readthedocs.io/en/latest/"),
    Package(pypi="notifiers", index_url="https://notifiers.readthedocs.io/en/latest/"),
    Package(pypi="pyee", index_url="https://pyee.readthedocs.io/en/latest/"),
    Package(pypi="inflection", index_url="https://inflection.readthedocs.io/en/latest/"),
    Package(pypi="nequip", index_url="https://nequip.readthedocs.io/en/latest/"),
    Package(pypi="pyfastx", index_url="https://pyfastx.readthedocs.io/en/latest/"),
    Package(pypi="kivymd", index_url="https://kivymd.readthedocs.io/en/latest/"),
    Package(pypi="oauthenticator", index_url="https://oauthenticator.readthedocs.io/en/latest/"),
    Package(pypi="flask-rq2", index_url="https://flask-rq2.readthedocs.io/en/latest/"),
    Package(pypi="logutils", index_url="https://logutils.readthedocs.io/en/latest/"),
    Package(pypi="pytest-logger", index_url="https://pytest-logger.readthedocs.io/en/latest/"),
    Package(pypi="pymatreader", index_url="https://pymatreader.readthedocs.io/en/latest/"),
    Package(pypi="wonderwords", index_url="https://wonderwords.readthedocs.io/en/latest/"),
    Package(pypi="class-registry", index_url="https://class-registry.readthedocs.io/en/latest/"),
    Package(pypi="cached-path", index_url="https://cached-path.readthedocs.io/en/latest/"),
    Package(pypi="django-enum", index_url="https://django-enum.readthedocs.io/en/stable/"),
    Package(pypi="napalm", index_url="https://napalm.readthedocs.io/en/latest/"),
    Package(pypi="twiggy", index_url="https://twiggy.readthedocs.io/en/stable/"),
    Package(pypi="tidyexc", index_url="https://tidyexc.readthedocs.io/en/latest/"),
    Package(pypi="pypac", index_url="https://pypac.readthedocs.io/en/latest/"),
    Package(pypi="yourdfpy", index_url="https://yourdfpy.readthedocs.io/en/latest/"),
    Package(pypi="tdda", index_url="https://tdda.readthedocs.io/en/latest/"),
    Package(pypi="fixit", index_url="https://fixit.readthedocs.io/en/stable/"),
    Package(pypi="jschon", index_url="https://jschon.readthedocs.io/en/latest/"),
    Package(pypi="httpstan", index_url="https://httpstan.readthedocs.io/en/latest/"),
    Package(pypi="gkeepapi", index_url="https://gkeepapi.readthedocs.io/en/latest/"),
    Package(pypi="parfive", index_url="https://parfive.readthedocs.io/en/stable/"),
    Package(pypi="pandapower", index_url="https://pandapower.readthedocs.io/en/latest/"),
    Package(pypi="cornice", index_url="https://cornice.readthedocs.io/en/latest/"),
    Package(pypi="glum", index_url="https://glum.readthedocs.io/en/latest/"),
    Package(pypi="pyorc", index_url="https://pyorc.readthedocs.io/en/stable/"),
    Package(pypi="aleph-alpha-client", index_url="https://aleph-alpha-client.readthedocs.io/en/latest/"),
    Package(pypi="pysparkling", index_url="https://pysparkling.readthedocs.io/en/latest/"),
    Package(pypi="vizro", index_url="https://vizro.readthedocs.io/en/stable/"),
    Package(pypi="aes-pkcs5", index_url="https://aes-pkcs5.readthedocs.io/en/latest/"),
    Package(pypi="pronto", index_url="https://pronto.readthedocs.io/en/stable/"),
    Package(pypi="flask-sitemap", index_url="https://flask-sitemap.readthedocs.io/en/latest/"),
    Package(pypi="pyhdfe", index_url="https://pyhdfe.readthedocs.io/en/stable/"),
    Package(pypi="pythreejs", index_url="https://pythreejs.readthedocs.io/en/stable/"),
    Package(pypi="backoff-utils", index_url="https://backoff-utils.readthedocs.io/en/latest/"),
    Package(pypi="pymem", index_url="https://pymem.readthedocs.io/en/latest/"),
    Package(pypi="reliability", index_url="https://reliability.readthedocs.io/en/latest/"),
    Package(pypi="web-poet", index_url="https://web-poet.readthedocs.io/en/stable/"),
    Package(pypi="upsetplot", index_url="https://upsetplot.readthedocs.io/en/stable/"),
    Package(pypi="drf-standardized-errors", index_url="https://drf-standardized-errors.readthedocs.io/en/latest/"),
    Package(pypi="dicomweb-client", index_url="https://dicomweb-client.readthedocs.io/en/latest/"),
    Package(pypi="enum-tools", index_url="https://enum-tools.readthedocs.io/en/latest/"),
    Package(pypi="mrjob", index_url="https://mrjob.readthedocs.io/en/latest/"),
    Package(pypi="rush", index_url="https://rush.readthedocs.io/en/latest/"),
    Package(pypi="attrs-strict", index_url="https://attrs-strict.readthedocs.io/en/latest/"),
    Package(pypi="autosemver", index_url="https://autosemver.readthedocs.io/en/latest/"),
    Package(pypi="qutip", index_url="https://qutip.readthedocs.io/en/stable/"),
    Package(pypi="represent", index_url="https://represent.readthedocs.io/en/latest/"),
    Package(pypi="ocrmypdf", index_url="https://ocrmypdf.readthedocs.io/en/latest/"),
    Package(pypi="qianfan", index_url="https://qianfan.readthedocs.io/en/latest/"),
    Package(pypi="asyncvnc", index_url="https://asyncvnc.readthedocs.io/en/latest/"),
    Package(pypi="win-precise-time", index_url="https://win-precise-time.readthedocs.io/en/latest/"),
    Package(pypi="pysubs2", index_url="https://pysubs2.readthedocs.io/en/latest/"),
    Package(pypi="mapply", index_url="https://mapply.readthedocs.io/en/stable/"),
    Package(pypi="targ", index_url="https://targ.readthedocs.io/en/latest/"),
    Package(pypi="qtawesome", index_url="https://qtawesome.readthedocs.io/en/latest/"),
    Package(pypi="nc-time-axis", index_url="https://nc-time-axis.readthedocs.io/en/latest/"),
    Package(pypi="infrahouse-core", index_url="https://infrahouse-core.readthedocs.io/en/latest/"),
    Package(pypi="haggis", index_url="https://haggis.readthedocs.io/en/stable/"),
    Package(pypi="conditional", index_url="https://conditional.readthedocs.io/en/latest/"),
    Package(pypi="gpiozero", index_url="https://gpiozero.readthedocs.io/en/stable/"),
    Package(pypi="rfc5424-logging-handler", index_url="https://rfc5424-logging-handler.readthedocs.io/en/latest/"),
    Package(pypi="fastobo", index_url="https://fastobo.readthedocs.io/en/latest/"),
    # ENTRY-LINE-MARKER
]
# fmt: on


SUPPORTED_PACKAGES: dict[str, Package] = {pkg.pypi: pkg for pkg in _packages}


def get_packages(package: str | None) -> list[Package]:
    if package is None:
        return list(SUPPORTED_PACKAGES.values())
    else:
        if package not in SUPPORTED_PACKAGES:
            console.fatal(f"No package named {package}")
        return [SUPPORTED_PACKAGES[package]]
